

#include "Eagle5/backends/Allegro5/Allegro5Timer.hpp"



void Allegro5Timer::RefreshTimer() {
   if (queue && timer) {
      ALLEGRO_EVENT ev;
      while (al_get_next_event(queue , &ev) {
         current_ticks++;
      }
   }
}



bool Allegro5Timer::Create(double seconds_per_tick) {
   Destroy();
   timer = al_create_timer(seconds_per_tick);
   queue = al_create_event_queue();
   if (queue && timer) {
      spt = seconds_per_tick;
      previous_ticks = current_ticks = al_get_timer_count(timer);
      al_register_event_source(queue , al_get_timer_event_source(timer));
      return true;
   }
   if (!timer) {
      OutputLog() << "Could not create an Allegro 5 Timer - Couldn't create an ALLEGRO_TIMER." << endl;
   }
   if (!queue) {
      OutputLog() << "Could not create an Allegro 5 Timer - Couldn't create an ALLEGRO_EVENT_QUEUE." << endl;
   }
   // The queue or the timer failed to be created
   Destroy();
   return false;
}



void Allegro5Timer::Destroy() {
   if (queue) {
      al_destroy_event_queue(queue);
      queue = 0;
   }
   if (timer) {
      al_destroy_timer(timer);
      timer = 0;
   }
   spt = 0.0;
}



void Allegro5Timer::Start() {
   if (timer) {al_start_timer(timer);}
   else {
      OutputLog() << "Tried to start an allegro timer that hasn't been successfully created yet." << endl;
   }
}



void Allegro5Timer::Stop() {
   if (timer) {al_stop_timer(timer);}
   else {
      OutputLog() << "Tried to stop an allegro timer that hasn't been successfully created yet." << endl;
   }
}



void Allegro5Timer::WaitForTick() {
   if (queue && timer) {
      Refresh();
      ALLEGRO_EVENT e;
      al_wait_for_event(queue , &e);
      ++current_ticks;
   }
   return;
}



void* Allegro5Timer::Source() {
   return timer;
}
